import os
import shutil
from django.core.management.base import BaseCommand

class Command(BaseCommand):
    help = "Copy the django_admin_boilerplate app to the current Django project"

    def handle(self, *args, **kwargs):
        package_root = os.path.dirname(os.path.abspath(__file__))
        # print("package_root:  ", package_root, "\n")
        app_src = os.path.join(package_root, "..", "..", "..", "django_admin_boilerplate")
        # print("app_src:  ", app_src, "\n")
        project_root = os.getcwd()
        app_dest = os.path.join(project_root, "django_admin_boilerplate")
        # print("app_dest:  ", app_dest, "\n")
        if os.path.exists(app_dest):
            self.stdout.write(self.style.WARNING("Skipping copy: 'django_admin_boilerplate' already exists."))
        else:
            shutil.copytree(app_src, app_dest)
            self.stdout.write(self.style.SUCCESS(f"Successfully copied 'django_admin_boilerplate' to {project_root}"))



from django.apps import AppConfig

class DjangoAdminBoilerplateConfig(AppConfig):
    name = 'django_admin_boilerplate'

    def ready(self):
        import django_admin_boilerplate.management.commands



# Generated by Django 4.2.19 on 2025-03-02 15:15

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='ThemeSetting',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('theme', models.CharField(choices=[('default', 'Default'), ('blue', 'Blue Theme'), ('green', 'Green Theme'), ('dark', 'Dark Mode')], default='default', max_length=50)),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
